@@ -1,74 +1,7 @@
 from .types import *
 
 
-class NetsplashGetInterfaces(NCSInstance):
-
-    _path = "/action/services/netsplash-get-interfaces"
-
-    _nsmap = {
-        "action":"urn:ietf:params:xml:ns:yang:1",
-        "services":"http://tail-f.com/ns/ncs",
-        "netsplash-get-interfaces":"http://umnet.umich.edu/netsplash",
-        }
-
-    def initialize_model(self):
-
-        self.ip_or_name = Choice(['device-hostname','device-ip'])
-        self.ip_or_name.device_ip = Leaf(str)
-        self.ip_or_name.device_hostname = Leaf(str)
-
-class NetsplashGetSwitchesByZone(NCSInstance):
-
-    _path = "/action/services/netsplash-get-switches-by-zone"
-
-    _nsmap = {
-        "action":"urn:ietf:params:xml:ns:yang:1",
-        "services":"http://tail-f.com/ns/ncs",
-        "netsplash-get-switches-by-zone":"http://umnet.umich.edu/netsplash",
-        }
-
-    def initialize_model(self):
-        self.zone = Leaf(str)
-
-
-class NetsplashUpdateInterfaces(NCSInstance):
-
-    _path = "/action/services/netsplash-update-interfaces"
-
-    _nsmap = {
-        "action":"urn:ietf:params:xml:ns:yang:1",
-        "services":"http://tail-f.com/ns/ncs",
-        "netsplash-update-interfaces":"http://umnet.umich.edu/netsplash",
-        }
-
-    def initialize_model(self):
-
-        self.switch = Leaf(str)
-        self.zone = Leaf(str)
-        self.switchport = List(NetsplashSwitchport)
-
-
-class NetsplashSwitchport(Choice):
-    
-    def initialize_model(self, choice=None):
-
-        # the choice initializer creates empty containers
-        # for 'access' and 'default' for us
-        super().__init__(['access','default'])
-        
-        # now we need to fill in everything else
-        self.name = Leaf(str)
-        self.access.description = Leaf(str)
-        self.access.vlan_name = Leaf(str)
-        self.access.admin_status = Leaf(str)
-        self.access.voip_enabled = Leaf(bool)
-
-        # can't apply choice until after we've initialized
-        # all options!
-        if choice:
-            self.choose(choice)
-
-class Devices(NCSInstance):
+class Devices(NCSObject):
 
     _path = "/config/devices"
 
@@ -84,7 +17,7 @@ class Devices(NCSInstance):
     def initialize_model(self):
         self.device = List(Device)
 
-class Device(NCSInstance):
+class Device(NCSObject):
 
     _path = "/config/devices/device"
 
@@ -123,7 +56,7 @@ class Device(NCSInstance):
         self.um_building.room_no = Leaf(str)
 
 
-class Switchport(NCSInstance):
+class Switchport(NCSObject):
 
     def initialize_model(self):
 
@@ -141,13 +74,13 @@ class Switchport(NCSInstance):
         self.mode.mode_choice.trunk.vlan_list = LeafList(str)
         self.mode.mode_choice.default = Container()
 
-class Network(NCSInstance):
+class Network(NCSObject):
 
     _path = "/config/services/network"
     _nsmap = {
             "config":"http://tail-f.com/ns/config/1.0",
             "services":"http://tail-f.com/ns/ncs",
-            "network":"http://example.com/umnet-network",
+            "network":"http://example.com/umnet-network"
             }
 
     def initialize_model(self):
@@ -167,7 +100,7 @@ class Network(NCSInstance):
         self.layer3.ingress_acl = Leaf(str)
         self.layer3.egress_acl = Leaf(str)
 
-class Networks(NCSInstance):
+class Networks(NCSObject):
 
     _path = "/config/services"
     _nsmap = {
@@ -180,7 +113,7 @@ class Networks(NCSInstance):
         self.network = List(Network)
         self.network.set_ns("http://example.com/umnet-network")
 
-class NGFWVsyses(NCSInstance):
+class NGFWVsyses(NCSObject):
     _path = "/config/services"
     _nsmap = {
             "config":"http://tail-f.com/ns/config/1.0",
@@ -188,15 +121,15 @@ class NGFWVsyses(NCSInstance):
             }
     def initialize_model(self):
         self.ngfw_vsys = List(NGFWVsys)
-        sels.ngfw_vsys.set_ns("http://umnet.umich.edu/umnet-vrf")
+        self.ngfw_vsys.set_ns("http://umnet.umich.edu/umnet-vrf")
 
-class NGFWVsys(NCSInstance):
+class NGFWVsys(NCSObject):
 
     def initialize_model(self):
         self.name = Leaf('str')
         self.asn = Leaf('str')
         
-class Vrf(NCSInstance):
+class Vrf(NCSObject):
 
     def initialize_model(self):
 
@@ -207,7 +140,7 @@ class Vrf(NCSInstance):
 
         self.vrf_no = Leaf(int)
 
-class Vrfs(NCSInstance):
+class Vrfs(NCSObject):
 
     _path = "/config/services"
     _nsmap = {
@@ -219,66 +152,70 @@ class Vrfs(NCSInstance):
         self.vrf = List(Vrf)
         self.vrf.set_ns('http://umnet.umich.edu/umnet-vrf')
 
-class BaseconfProfile(NCSInstance):
+class BaseconfProfile(NCSObject):
     '''
     For the ncs migration project we don't actually
     profiles, we just need to be able to add devices to
     ones that already exist. As a result we're not defining
     any groups or profile details here.
     '''
-
+    _nsmap = {
+            "config":"http://tail-f.com/ns/config/1.0",
+            "services":"http://tail-f.com/ns/ncs",
+            "baseconf":"http://umnet.umich.edu/umnet-baseconf",
+        }
+        
     def initialize_model(self):
         self.name = Leaf('str')
         self.devices = LeafList('str')
 
 
-class Baseconf(NCSInstance):
-    _path = "/config/services/baseconf"
+class Baseconf(NCSObject):
+    _path = "/config/services"
     _nsmap = {
             "config":"http://tail-f.com/ns/config/1.0",
             "services":"http://tail-f.com/ns/ncs",
-            "baseconf":"http://umnet.umich.edu/umnet-baseconf",
             }
 
+    _name = "baseconf"
+    _ns = "http://umnet.umich.edu/umnet-baseconf"
+
     def initialize_model(self):
         self.profile = List(BaseconfProfile)
 
 
 
-class Switch(NCSInstance):
-
+class Switch(NCSObject):
     def initialize_model(self):
         self.name = Leaf(str)
         self.switchport = List(Switchport)
 
-class SwitchUplinks(NCSInstance):
+class SwitchUplinks(NCSObject):
     def initialize_model(self):
         self.name = Leaf(str)
         self.uplink = List(Uplink)
 
-class Uplink(NCSInstance):
+class Uplink(NCSObject):
 
     def initialize_model(self):
         self.name = Leaf(str)
         self.uplink_type = Choice(['single-dl','al-to-al'])
         self.uplink_type.single_dl = Container()
-        self.uplink_type.single_dl.pri_or_sec = Choice(['primary','secondary'])
-        self.uplink_type.single_dl.pri_or_sec.primary = Container()
-        self.uplink_type.single_dl.pri_or_sec.primary.primary_router_ifname = Leaf(str)
-        self.uplink_type.single_dl.pri_or_sec.secondary = Container()
-        self.uplink_type.single_dl.pri_or_sec.secondary.secondary_router_ifname = Leaf(str)
+        self.uplink_type.single_dl.pri_or_sec = Choice(['primary_router_ifname','secondary_router_ifname'])
+        self.uplink_type.single_dl.pri_or_sec.primary_router_ifname = Leaf(str)
+        self.uplink_type.single_dl.pri_or_sec.secondary_router_ifname = Leaf(str)
 
         self.uplink_type.al_to_al = Container()
         self.uplink_type.al_to_al.remote_switch = Leaf(str)
         self.uplink_type.al_to_al.remote_interface = Leaf(str)
 
 
-class DistNetwork(NCSInstance):
+class DistNetwork(NCSObject):
 
     def initialize_model(self):
         self.name = Leaf(str)
 
-class Distribution(NCSInstance):
+class Distribution(NCSObject):
 
     _path = "/config/services/distribution"
     _nsmap = {
@@ -287,34 +224,34 @@ class Distribution(NCSInstance):
             "distribution":"http://umnet.umich.edu/distribution",
             }
 
-
     def initialize_model(self):
-    
+
         self.name = Leaf(str)
         self.legacy_zone = Leaf(bool, True)
         self.fabric = Leaf(str)
 
-        self.routing = Container()
+        self.routing = Container(hide_if_empty=True)
         self.routing.network = List(DistNetwork)
 
         # note that because we're only dealing with legacy zones
         # right now, the primary/secondary DLs can be modeled
         # as switches.
-        self.routing.primary_router = Switch()
-        self.routing.secondary_router = Switch()
+        self.routing.primary_router = Switch(hide_if_empty=True)
+        self.routing.secondary_router = Switch(hide_if_empty=True)
 
         self.switch = List(Switch)
 
-        self.uplinks = Container()
+        self.uplinks = Container(hide_if_empty=True)
         self.uplinks.switch = List(SwitchUplinks)
 
-class DHCPServerGroup(NCSInstance):
+class DHCPServerGroup(NCSObject):
 
     def initialize_model(self):
         self.name = Leaf(str)
         self.server_ip = LeafList(str)
 
-class Constants(NCSInstance):
+class Constants(NCSObject):
+    
     _path = "/config/services/constants/dhcp-server-group"
     _nsmap = {
             "config":"http://tail-f.com/ns/config/1.0",
